from collections import namedtuple

import aiohttp

from .logs import logger


class InfluxDB:
    def __init__(self, url: str, org: str, bucket: str, token: str) -> "InfluxDB":
        self.url = url
        self.org = org
        self.bucket = bucket
        self.headers = {"Authorization": f"Token {token}", "Content-Type": "text/plain"}

    async def check_settings(self) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.get(f"{self.url}/api/v2/orgs", headers=self.headers) as response:
                return response.status == 200

    async def insert(self, host: str, ports: namedtuple) -> None:
        payload = "\n".join(
            f'port_scan,host={host},port={p.port} state="{p.state}",protocol="{p.protocol}",service="{p.service}"'
            for p in ports
        )

        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.url}/api/v2/write?org={self.org}&bucket={self.bucket}&precision=s",
                headers=self.headers,
                data=payload,
            ) as response:
                if response.status != 204:
                    logger.error(f"Failed write to InfluxDB (HTTP {response.status}): {await response.text()}")
                    return False
                logger.info(f"Received HTTP {response.status} from InfluxDB")
                return True
