import argparse
from ipaddress import AddressValueError
from ipaddress import IPv4Network


def validate_cidr_or_ipv4(value: str) -> IPv4Network:
    """
    Validates whether a given value is a valid CIDR or IPv4 address
    by attempting return a newly constructed IPv4Network object.

    Args:
        value (str): The string value to be validated as CIDR or IPv4 address

    Returns:
        IPv4Network: An IPv4Network instance constructed with the input value

    Raises:
        argparse.ArgumentTypeError: If the input value is not a valid CIDR or IPv4 address
    """
    try:
        return IPv4Network(value)
    except AddressValueError as err:
        raise argparse.ArgumentTypeError(str(err))
